//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[Mentsu](-mentsu.md)

# Mentsu

[common]\
fun [Mentsu](-mentsu.md)(vararg tiles: [Tile](-tile/index.md)): [Mentsu](-mentsu/index.md)

fun [Mentsu](-mentsu.md)(tiles: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](-tile/index.md)&gt;): [Mentsu](-mentsu/index.md)

fun [Mentsu](-mentsu.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Mentsu](-mentsu/index.md)
